% called after getpred.m to make a timeseries.
yearday_start=str2num(get(h322,'String')); 
yearday_end=str2num(get(h332,'String')); 

if isempty(yearday_start) | isempty(yearday_end),
  disp(' ')
  disp('Start or end yeardays missing; no timeseries prediction')
  figure(2)
break
end

yd=yearday_start:(1/24):yearday_end;
yd=yd';

YD1=[yearday_start*0.98 yearday_end*1.02];

% begin with definition of some constants...
oneday=[335.62  0  322.55  1.97   334.63  0.99  -0.99  321.57  26.354];
% omegat has the tidal frequencies in rad/yearday.  It is defined in getpred.m

YEAR=str2num(get(h5,'String')); 
YEARLABEL=get(h5,'String');

if YEAR < 1970 | YEAR > 2037,
disp('constants for prediction year are not available')
break
end

load lun_node.dat
load v0u.dat
% the ordering of the constants in the above two files is:
%         M2   S2   N2      K2     O1     K1     P1      Q1   Mf

years=lun_node(:,1);
I=YEAR==years;
vou=v0u(I,2:10);
lunnod=lun_node(I,2:10);

JJ=1:9;
vou=(pi/180)*vou;
oneday=(pi/180)*oneday;
q=ones(size(yd));

% Start with calculation of zonal currents.
G=(pi/180)*AG(:,2)';
A=AG(:,1)'.*lunnod;
d=ones(size(yd))*A(JJ).*cos(yd*omegat(JJ) - q*oneday(JJ) + q*vou(JJ) - q*G(JJ) );

[kl lk]=size(d);
if lk>1,
ts1=sum(d')';
else
ts1=d;
end

% Now get meridional currents.
G=(pi/180)*AG(:,4)';
A=AG(:,3)'.*lunnod;
d=ones(size(yd))*A(JJ).*cos(yd*omegat(JJ) - q*oneday(JJ) + q*vou(JJ) - q*G(JJ) );

[kl lk]=size(d);
if lk>1,
ts2=sum(d')';
else
ts2=d;
end  

minU=min([ts1; ts2])*1.1;
maxU=max([ts1; ts2])*1.1;
maxU=max([abs(minU) abs(maxU)]);

% Now get elevation.
G=(pi/180)*AG(:,6)';
A=AG(:,5)'.*lunnod;
d=ones(size(yd))*A(JJ).*cos(yd*omegat(JJ) - q*oneday(JJ) + q*vou(JJ) - q*G(JJ) );

[kl lk]=size(d);
if lk>1,
ts3=sum(d')';
else
ts3=d;
end  

minE=min(ts3)*1.1;
maxE=max(ts3)*1.1;
maxE=max([abs(minE) abs(maxE)]);
% axes for current (yearday and current in cm/s)
A1=[YD1 -maxU maxU];
% axes for elevation (yearday and elevation in cm)
A2=[YD1 -maxE maxE];

figure(3)

subplot(311)
plot(yd,ts1,[0 365],[0 0],':k')
%xlabel(['Yearday ' YEARLABEL])
ylabel('Current (cm/s)')
title('TPXO.5, 0.5 deg Res. - Zonal Tidal Current')
axis(A1)
set(gca,'XTickLabel',[])


subplot(312)
plot(yd,ts2,[0 365],[0 0],':k')
%xlabel(['Yearday ' YEARLABEL])
ylabel('Current (cm/s)')
title('TPXO.5, 0.5 deg Res. - Meridional Tidal Current')
axis(A1)
set(gca,'XTickLabel',[])

 
subplot(313)
plot(yd,ts3,[0 365],[0 0],':k')
xlabel(['Yearday ' YEARLABEL])
ylabel('Elevation (cm)')
title('TPXO.5, 0.5 deg Res. - Elevation')
axis(A2)      

figure(2)

F=[yd  ts1 ts2 ts3];

disp('  ')
disp('Done with Prediction')
